@@ -200,6 +200,23 @@ class DataFrame:
     def fetchall(self):
         return list(self._cursor)
 
+    def display(
+        self,
+        limit: int = 5,
+        display_width: typing.Union[bool, int] = True,
+        max_column_width: int = 30,
+        colorize: bool = True,
+    ):
+        from .display import ascii_table
+
+        return ascii_table(
+            self,
+            limit=limit,
+            display_width=display_width,
+            max_column_width=max_column_width,
+            colorize=colorize,
+        )
+
     def to_batches(self, batch_size: int = 1000):
         """
         Batch a DataFrame into batches of `size` records.
@@ -277,4 +294,30 @@ class DataFrame:
     def __str__(self) -> str:
         from .display import ascii_table
 
-        return ascii_table(self)
+        return ascii_table(self) + f"\n [ {self.rowcount} rows x {self.columncount} columns ]"
+
+    def __repr__(self) -> str:
+        size: int = 10
+        try:
+            from IPython import get_ipython
+
+            i_am_in_a_notebook = get_ipython() is not None
+        except ImportError:
+            i_am_in_a_notebook = False
+
+        if i_am_in_a_notebook:
+            from IPython.display import HTML
+            from IPython.display import display
+
+            from .display import html_table
+
+            html = html_table([r.as_dict for i, r in enumerate(iter(self)) if i < size], size)
+            display(HTML(html))
+            return ""
+        else:
+            from .display import ascii_table
+
+            return (
+                ascii_table(self, limit=size)
+                + f"\n [ {self.rowcount} rows x {self.columncount} columns ]"
+            )
